@@ -24,6 +24,7 @@ from pyzo.util.qt import QtCore, QtGui, QtWidgets
 from pyzo.core.splash import SplashWidget
 from pyzo.util import paths
 from pyzo.util import zon as ssdf  # zon is ssdf-light
+from pyzo import translate
 
 
 class MainWindow(QtWidgets.QMainWindow):
@@ -35,7 +36,7 @@ class MainWindow(QtWidgets.QMainWindow):
         
         # Init window title and application icon
         # Set title to something nice. On Ubuntu 12.10 this text is what
-        # is being shown at the fancy title bar (since it's not properly 
+        # is being shown at the fancy title bar (since it's not properly
         # updated)
         self.setMainTitle()
         loadAppIcons()
@@ -70,9 +71,9 @@ class MainWindow(QtWidgets.QMainWindow):
         # Init dockwidget settings
         self.setTabPosition(QtCore.Qt.AllDockWidgetAreas,QtWidgets.QTabWidget.South)
         self.setDockOptions(
-                QtWidgets.QMainWindow.AllowNestedDocks
-            |  QtWidgets.QMainWindow.AllowTabbedDocks
-            #|  QtWidgets.QMainWindow.AnimatedDocks
+                QtWidgets.QMainWindow.AllowNestedDocks |
+                QtWidgets.QMainWindow.AllowTabbedDocks
+                #|  QtWidgets.QMainWindow.AnimatedDocks
             )
         
         # Set window atrributes
@@ -134,7 +135,7 @@ class MainWindow(QtWidgets.QMainWindow):
         """
         self._ispainted = False
         self.update()
-        while not self._ispainted:   
+        while not self._ispainted:
             QtWidgets.qApp.flush()
             QtWidgets.qApp.processEvents()
             time.sleep(0.01)
@@ -145,6 +146,7 @@ class MainWindow(QtWidgets.QMainWindow):
         from pyzo.core.editorTabs import EditorTabs
         from pyzo.core.shellStack import ShellStackWidget
         from pyzo.core import codeparser
+        from pyzo.core.history import CommandHistory
         from pyzo.tools import ToolManager
         
         # Instantiate tool manager
@@ -165,7 +167,10 @@ class MainWindow(QtWidgets.QMainWindow):
         
         # Create floater for shell
         self._shellDock = dock = QtWidgets.QDockWidget(self)
-        dock.setFeatures(dock.DockWidgetMovable)
+        if pyzo.config.settings.allowFloatingShell:
+            dock.setFeatures(dock.DockWidgetMovable | dock.DockWidgetFloatable)
+        else:
+            dock.setFeatures(dock.DockWidgetMovable)
         dock.setObjectName('shells')
         dock.setWindowTitle('Shells')
         self.addDockWidget(QtCore.Qt.RightDockWidgetArea, dock)
@@ -174,6 +179,9 @@ class MainWindow(QtWidgets.QMainWindow):
         pyzo.shells = ShellStackWidget(self)
         dock.setWidget(pyzo.shells)
         
+        # Initialize command history
+        pyzo.command_history = CommandHistory('command_history.py')
+        
         # Create the default shell when returning to the event queue
         callLater(pyzo.shells.addShell)
         
@@ -197,7 +205,7 @@ class MainWindow(QtWidgets.QMainWindow):
         if pyzo.config.state.newUser and not pyzo.config.state.loadedTools:
             pyzo.toolManager.loadTool('pyzosourcestructure')
             pyzo.toolManager.loadTool('pyzofilebrowser', 'pyzosourcestructure')
-        elif pyzo.config.state.loadedTools: 
+        elif pyzo.config.state.loadedTools:
             for toolId in pyzo.config.state.loadedTools:
                 pyzo.toolManager.loadTool(toolId)
     
@@ -213,7 +221,7 @@ class MainWindow(QtWidgets.QMainWindow):
             if os.path.isfile(path):
                 pass
             elif name == path:
-                path = 'unsaved'
+                path = translate("main", 'unsaved')
             else:
                 pass  # We hope the given path is informative
             # Set title
@@ -227,7 +235,7 @@ class MainWindow(QtWidgets.QMainWindow):
     
     def saveWindowState(self):
         """ Save:
-            * which tools are loaded 
+            * which tools are loaded
             * geometry of the top level windows
             * layout of dockwidgets and toolbars
         """
@@ -266,7 +274,7 @@ class MainWindow(QtWidgets.QMainWindow):
             try:
                 geometry = pyzo.config.state.windowGeometry
                 geometry = base64.decodebytes(geometry.encode('ascii'))
-                self.restoreGeometry(geometry)  
+                self.restoreGeometry(geometry)
             except Exception as err:
                 print('Could not restore window geomerty: ' + str(err))
     
@@ -315,7 +323,7 @@ class MainWindow(QtWidgets.QMainWindow):
             
             # Set style if there is no style yet
             if not pyzo.config.view.qtstyle:
-                pyzo.config.view.qtstyle = pyzo.defaultQtStyleName 
+                pyzo.config.view.qtstyle = pyzo.defaultQtStyleName
         
         # Init
         if not stylename:
@@ -345,6 +353,7 @@ class MainWindow(QtWidgets.QMainWindow):
         
         # Save settings
         pyzo.saveConfig()
+        pyzo.command_history.save()
         
         # Stop command server
         commandline.stop_our_server()
@@ -366,7 +375,7 @@ class MainWindow(QtWidgets.QMainWindow):
         
         # Close tools
         for toolname in pyzo.toolManager.getLoadedTools():
-            tool = pyzo.toolManager.getTool(toolname) 
+            tool = pyzo.toolManager.getTool(toolname)
             tool.close()
         
         # Stop all threads (this should really only be daemon threads)
@@ -378,7 +387,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 except Exception:
                     pass
         
-#         # Wait for threads to die ... 
+#         # Wait for threads to die ...
 #         # This should not be necessary, but I used it in the hope that it
 #         # would prevent the segfault on Python3.3. It didn't.
 #         timeout = time.time() + 0.5
@@ -495,7 +504,7 @@ def loadIcons():
                 name = name.replace('pyzo_', '')  # discart prefix
                 ffname = os.path.join(iconDir,fname)
                 # Create icon
-                icon = QtGui.QIcon() 
+                icon = QtGui.QIcon()
                 icon.addFile(ffname, QtCore.QSize(16,16))
                 # Store
                 pyzo.icons[name] = icon
@@ -522,6 +531,8 @@ def loadFonts():
     # Load fonts that are in the fonts directory
     if os.path.isdir(fontDir):
         for fname in os.listdir(fontDir):
+            if 'oblique' in fname.lower():  # issue #461
+                continue
             if os.path.splitext(fname)[1].lower() in ['.otf', '.ttf']:
                 try:
                     db.addApplicationFont( os.path.join(fontDir, fname) )
@@ -530,7 +541,7 @@ def loadFonts():
 
 
 class _CallbackEventHandler(QtCore.QObject):
-    """ Helper class to provide the callLater function. 
+    """ Helper class to provide the callLater function.
     """
     
     def __init__(self):
@@ -554,12 +565,12 @@ class _CallbackEventHandler(QtCore.QObject):
 
 def callLater(callback, *args):
     """ callLater(callback, *args)
-    Post a callback to be called in the main thread. 
+    Post a callback to be called in the main thread.
     """
     _callbackEventHandler.postEventWithCallback(callback, *args)
     
 # Create callback event handler instance and insert function in pyzo namespace
-_callbackEventHandler = _CallbackEventHandler()   
+_callbackEventHandler = _CallbackEventHandler()
 pyzo.callLater = callLater
 
 
@@ -577,7 +588,7 @@ class Groceries(list):
     \"\"\" Overloaded list class.
     \"\"\"
     def append_defaults(self):
-        spam = 'yum'  
+        spam = 'yum'
         pie = 3.14159
         self.extend([spam, pie])
 
