@@ -4,7 +4,7 @@
 # Pyzo is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
 
-""" 
+"""
 Module to integrate GUI event loops in the Pyzo interpreter.
 
 This specifies classes that all have the same interface. Each class
@@ -20,7 +20,7 @@ import time
 from pyzokernel import printDirect
 
 
-# Warning message. 
+# Warning message.
 mainloopWarning = """
 Note: The GUI event loop is already running in the pyzo kernel. Be aware
 that the function to enter the main loop does not block.
@@ -28,18 +28,27 @@ that the function to enter the main loop does not block.
 
 # Qt has its own message
 mainloopWarning_qt = """
-Note on using QApplication.exec_(): 
+Note on using QApplication.exec_():
 The GUI event loop is already running in the pyzo kernel, and exec_()
 does not block. In most cases your app should run fine without the need
 for modifications. For clarity, this is what the pyzo kernel does:
 - Prevent deletion of objects in the local scope of functions leading to exec_()
 - Prevent system exit right after the exec_() call
-""".strip()+"\n"
+""".lstrip()
 
 
+# Print the main loop warning at most once
+_printed_warning = False
+def print_mainloop_warning(msg=None):
+    global _printed_warning
+    if not _printed_warning:
+        _printed_warning = True
+        msg = msg or mainloopWarning
+        printDirect(msg)
+
 
 class App_base:
-    """ Defines the interface. 
+    """ Defines the interface.
     """
     
     def process_events(self):
@@ -55,7 +64,7 @@ class App_base:
     
     def run(self, repl_callback, sleeptime=0.01):
         """ Very simple mainloop. Subclasses can overload this to use
-        the native event loop. Attempt to process GUI events at least 
+        the native event loop. Attempt to process GUI events at least
         every sleeptime seconds.
         """
         
@@ -95,13 +104,13 @@ class App_base:
 
 
 
-class App_tk(App_base):    
+class App_tk(App_base):
     """ Tries to import tkinter and returns a withdrawn tkinter root
     window.  If tkinter is already imported or not available, this
-    returns None.  
+    returns None.
     Modifies tkinter's mainloop with a dummy so when a module calls
     mainloop, it does not block.
-    """    
+    """
     def __init__(self):
         
         # Try importing
@@ -115,7 +124,7 @@ class App_tk(App_base):
         # tkinter.Tk() has a mainloop method, which will simply call
         # tkinter.mainloop().
         def dummy_mainloop(*args,**kwargs):
-            printDirect(mainloopWarning)
+            print_mainloop_warning()
         tkinter.Misc.mainloop = dummy_mainloop
         tkinter.mainloop = dummy_mainloop
                 
@@ -153,11 +162,11 @@ class App_fltk(App_base):
         
         # Replace mainloop with a dummy
         def dummyrun(*args,**kwargs):
-            printDirect(mainloopWarning)
+            print_mainloop_warning()
         fl.Fl.run = types.MethodType(dummyrun, fl.Fl)
         
         # Store the app instance to process events
-        self.app =  fl.Fl   
+        self.app =  fl.Fl
         
         # Notify that we integrated the event loop
         self.app._in_event_loop = 'Pyzo'
@@ -169,16 +178,16 @@ class App_fltk(App_base):
 
 
 class App_fltk2(App_base):
-    """ Hijack fltk 2.    
+    """ Hijack fltk 2.
     """
     def __init__(self):
         # Try importing
-        import fltk2 as fl        
+        import fltk2 as fl
         
         # Replace mainloop with a dummy
         def dummyrun(*args,**kwargs):
-            printDirect(mainloopWarning)    
-        fl.run = dummyrun    
+            print_mainloop_warning()
+        fl.run = dummyrun
         
         # Return the app instance to process events
         self.app = fl
@@ -188,7 +197,7 @@ class App_fltk2(App_base):
     
     def process_events(self):
         # is this right?
-        self.app.wait(0) 
+        self.app.wait(0)
 
 
 
@@ -209,7 +218,7 @@ class App_tornado(App_base):
         
         # Replace mainloop with a dummy
         def dummy_start():
-            printDirect(mainloopWarning)
+            print_mainloop_warning()
             sys._pyzoInterpreter.ignore_sys_exit = True
             self.app.add_callback(reset_sys_exit)
         def dummy_stop():
@@ -247,11 +256,19 @@ class App_tornado(App_base):
     
     def run(self, repl_callback, sleeptime=None):
         from tornado.ioloop import PeriodicCallback
-        # Create timer 
+        # Create timer
         self._timer = PeriodicCallback(repl_callback, 0.05*1000)
         self._timer.start()
         # Enter mainloop
         self.app._original_start()
+        while True:
+            try:
+                self.app._original_start()
+            except KeyboardInterrupt:
+                self._keyboard_interrupt()
+                self.app._original_stop()
+                continue
+            break
     
     def quit(self):
         self.app._original_stop()
@@ -265,7 +282,7 @@ class App_qt(App_base):
     def __init__(self):
         import types
         
-        # Try importing qt        
+        # Try importing qt
         QtGui, QtCore = self.importCoreAndGui()
         self._QtGui, self._QtCore = QtGui, QtCore
         
@@ -277,16 +294,16 @@ class App_qt(App_base):
         class QApplication_hijacked(QtGui.QApplication):
             """ QApplication_hijacked(*args, **kwargs)
             
-            Hijacked QApplication class. This class has a __new__() 
-            method that always returns the global application 
+            Hijacked QApplication class. This class has a __new__()
+            method that always returns the global application
             instance, i.e. QtGui.qApp.
             
             The QtGui.qApp instance is an instance of the original
-            QtGui.QApplication, but with its __init__() and exec_() 
+            QtGui.QApplication, but with its __init__() and exec_()
             methods replaced.
             
             You can subclass this class; the global application instance
-            will be given the methods and attributes so it will behave 
+            will be given the methods and attributes so it will behave
             like the subclass.
             """
             def __new__(cls, *args, **kwargs):
@@ -328,7 +345,7 @@ class App_qt(App_base):
                 return theApp
             
             def __init__(self, *args, **kwargs):
-               pass
+                pass
             
             def exec_(self, *args, **kwargs):
                 """ This function does nothing, except printing a
@@ -336,7 +353,7 @@ class App_qt(App_base):
                 quite hard if an object goes out of scope, and the error
                 is not obvious.
                 """
-                printDirect(mainloopWarning_qt+'\n')
+                print_mainloop_warning(mainloopWarning_qt)
                 
                 # Store local namespaces (scopes) of any functions that
                 # precede this call. It might have a widget or application
@@ -363,7 +380,7 @@ class App_qt(App_base):
                 pass
         
         
-        # Instantiate application object 
+        # Instantiate application object
         self.app = QApplication_hijacked([''])
         
         # Keep it alive even if all windows are closed
@@ -395,7 +412,7 @@ class App_qt(App_base):
     
     
     def run(self, repl_callback, sleeptime=None):
-        # Create timer 
+        # Create timer
         timer = self._timer = self._QtCore.QTimer()
         timer.setSingleShot(False)
         timer.setInterval(0.05*1000)  # ms
@@ -418,9 +435,9 @@ class App_pyqt5(App_qt):
     """
     
     def importCoreAndGui(self):
-        # Try importing qt        
-        import PyQt5
-        from PyQt5 import QtGui, QtCore, QtWidgets
+        # Try importing qt
+        import PyQt5  # noqa
+        from PyQt5 import QtGui, QtCore, QtWidgets  # noqa
         return QtWidgets, QtCore  # QApp sits on QtWidgets
 
 
@@ -429,40 +446,49 @@ class App_pyqt4(App_qt):
     """
     
     def importCoreAndGui(self):
-        # Try importing qt        
-        import PyQt4
+        # Try importing qt
+        import PyQt4  # noqa
         from PyQt4 import QtGui, QtCore
         return QtGui, QtCore
     
+class App_pyside2(App_qt):
+    """ Hijack the PySide2 mainloop.
+    """
+    
+    def importCoreAndGui(self):
+        # Try importing qt
+        import PySide2  # noqa
+        from PySide2 import QtGui, QtCore, QtWidgets  # noqa
+        return QtWidgets, QtCore  # QApp sits on QtWidgets
     
 class App_pyside(App_qt):
     """ Hijack the PySide mainloop.
     """
     
     def importCoreAndGui(self):
-        # Try importing qt        
-        import PySide
+        # Try importing qt
+        import PySide  # noqa
         from PySide import QtGui, QtCore
         return QtGui, QtCore
 
 
 
 class App_wx(App_base):
-    """ Hijack the wxWidgets mainloop.    
-    """ 
+    """ Hijack the wxWidgets mainloop.
+    """
     
     def __init__(self):
         
         # Try importing
         try:
             import wx
-        except ImportError:            
+        except ImportError:
             # For very old versions of WX
             import wxPython as wx
         
         # Create dummy mainloop to replace original mainloop
         def dummy_mainloop(*args, **kw):
-            printDirect(mainloopWarning)
+            print_mainloop_warning()
         
         # Depending on version, replace mainloop
         ver = wx.__version__
@@ -480,10 +506,11 @@ class App_wx(App_base):
             # Unable to find either wxPython version 2.4 or >= 2.5."
             raise ImportError
         
+        self._orig_mainloop = orig_mainloop
         # Store package wx
         self.wx = wx
         
-        # Get and store the app instance to process events 
+        # Get and store the app instance to process events
         app = wx.GetApp()
         if app is None:
             app = wx.App(False)
@@ -496,16 +523,16 @@ class App_wx(App_base):
     def process_events(self):
         wx = self.wx
         
-        # This bit is really needed        
-        old = wx.EventLoop.GetActive()                       
+        # This bit is really needed
+        old = wx.EventLoop.GetActive()
         eventLoop = wx.EventLoop()
-        wx.EventLoop.SetActive(eventLoop)                        
+        wx.EventLoop.SetActive(eventLoop)
         while eventLoop.Pending():
             eventLoop.Dispatch()
         
         # Process and reset
         self.app.ProcessIdle() # otherwise frames do not close
-        wx.EventLoop.SetActive(old)   
+        wx.EventLoop.SetActive(old)
 
 
 
@@ -520,13 +547,13 @@ class App_gtk(App_base):
         
         # Replace mainloop with a dummy
         def dummy_mainloop(*args, **kwargs):
-            printDirect(mainloopWarning)        
+            print_mainloop_warning()
         gtk.mainloop = dummy_mainloop
         gtk.main = dummy_mainloop
         
         # Replace main_quit with a dummy too
         def dummy_quit(*args, **kwargs):
-            pass        
+            pass
         gtk.main_quit = dummy_quit
         gtk.mainquit = dummy_quit
         
@@ -542,6 +569,6 @@ class App_gtk(App_base):
     
     def process_events(self):
         gtk = self.app
-        while gtk.events_pending():            
+        while gtk.events_pending():
             gtk.main_iteration(False)
 
