@@ -33,7 +33,7 @@ import shlex
 from codeop import CommandCompiler
 import traceback
 import keyword
-import inspect # Must be in this namespace
+import inspect # noqa - Must be in this namespace
 import bdb
 from distutils.version import LooseVersion as LV
 
@@ -50,9 +50,9 @@ sys.last_traceback = None
 # Set Python version and get some names
 PYTHON_VERSION = sys.version_info[0]
 if PYTHON_VERSION < 3:
-    ustr = unicode
+    ustr = unicode  # noqa
     bstr = str
-    input = raw_input
+    input = raw_input  # noqa
 else:
     ustr = str
     bstr = bytes
@@ -146,7 +146,7 @@ class PyzoInterpreter:
         self.ignore_sys_exit = False
         
         # Information for debugging. If self._dbFrames, we're in debug mode
-        # _dbFrameIndex starts from 1 
+        # _dbFrameIndex starts from 1
         self._dbFrames = []
         self._dbFrameIndex = 0
         self._dbFrameName = ''
@@ -189,17 +189,17 @@ class PyzoInterpreter:
                 sys.path.remove(p)
     
     
-    def run(self):    
+    def run(self):
         """ Run (start the mainloop)
         
-        Here we enter the main loop, which is provided by the guiApp. 
-        This event loop calls process_commands on a regular basis. 
+        Here we enter the main loop, which is provided by the guiApp.
+        This event loop calls process_commands on a regular basis.
         
         We may also enter the debug intereaction loop, either from a
         request for post-mortem debugging, or *during* execution by
         means of a breakpoint. When in this debug-loop, the guiApp event
         loop lays still, but the debug-loop does call process-commands
-        for user interaction. 
+        for user interaction.
         
         When the user wants to quit, SystemExit is raised (one way or
         another). This is detected in process_commands and the exception
@@ -219,10 +219,11 @@ class PyzoInterpreter:
         
         # Enter main
         try:
-            self.guiApp.run(self.process_commands, self.sleeptime) 
+            self.guiApp.run(self.process_commands, self.sleeptime)
         except SystemExit:
             # Set self._exitException if it is not set yet
-            type, value, tb = sys.exc_info();  del tb
+            type, value, tb = sys.exc_info()
+            del tb
             if self._exitException is None:
                 self._exitException = value
         
@@ -281,7 +282,7 @@ class PyzoInterpreter:
             plat = 'Windows (%i bits)' % NBITS
         else:
             NBITS = 8 * struct.calcsize("P")
-            plat = '%s (%i bits)' % (sys.platform, NBITS) 
+            plat = '%s (%i bits)' % (sys.platform, NBITS)
         printDirect("%s %s on %s.\n" %
                     (thename, sys.version.split('[')[0].rstrip(), plat))
         
@@ -294,7 +295,7 @@ class PyzoInterpreter:
         if guiError:
             pyzoBanner += '. ' + guiError + '\n'
         elif guiName:
-            pyzoBanner += ' with integrated event loop for ' 
+            pyzoBanner += ' with integrated event loop for '
             pyzoBanner += guiName + '.\n'
         else:
             pyzoBanner += '.\n'
@@ -307,7 +308,7 @@ class PyzoInterpreter:
             try:
                 self._load_ipyhon()
             except Exception:
-                type, value, tb = sys.exc_info();
+                type, value, tb = sys.exc_info()
                 del tb
                 printDirect('IPython could not be loaded: %s\n' % str(value))
                 self._ipython = None
@@ -319,7 +320,7 @@ class PyzoInterpreter:
         # Notify about project path
         projectPath = startup_info['projectPath']
         if projectPath:
-            printDirect('Prepending the project path %r to sys.path\n' % 
+            printDirect('Prepending the project path %r to sys.path\n' %
                 projectPath)
         
         # Write tips message.
@@ -334,7 +335,7 @@ class PyzoInterpreter:
                 "object?   -> Details about 'object', "
                 "use 'object??' for extra details.\n")
         else:
-            printDirect("Type 'help' for help, " + 
+            printDirect("Type 'help' for help, " +
                         "type '?' for a list of *magic* commands.\n")
         
         # Notify the running of the script
@@ -416,7 +417,7 @@ class PyzoInterpreter:
             if startDir and os.path.isdir(startDir):
                 os.chdir(startDir)
             else:
-                os.chdir(os.path.expanduser('~')) # home dir 
+                os.chdir(os.path.expanduser('~')) # home dir
     
     
     def _run_startup_code(self, startup_info):
@@ -435,12 +436,12 @@ class PyzoInterpreter:
             if firstline.startswith('#AFTER_GUI'):
                 self._codeToRunOnStartup = script
             else:
-                self.context._stat_interpreter.send('Busy') 
+                self.context._stat_interpreter.send('Busy')
                 msg = {'source': script, 'fname': '<startup>', 'lineno': 0}
                 self.runlargecode(msg, True)
         elif script and os.path.isfile(script):
             # Run script
-            self.context._stat_interpreter.send('Busy') 
+            self.context._stat_interpreter.send('Busy')
             self.runfile(script)
         else:
             # Nothing to run
@@ -461,6 +462,7 @@ class PyzoInterpreter:
             elif guiName == 'AUTO':
                 for tryName, tryApp in [('PYQT5', guiintegration.App_pyqt5),
                                         ('PYQT4', guiintegration.App_pyqt4),
+                                        ('PYSIDE2', guiintegration.App_pyside2),
                                         ('PYSIDE', guiintegration.App_pyside),
                                         #('WX', guiintegration.App_wx),
                                         ('TK', guiintegration.App_tk),
@@ -481,6 +483,8 @@ class PyzoInterpreter:
                 self.guiApp = guiintegration.App_tornado()
             elif guiName == 'PYSIDE':
                 self.guiApp = guiintegration.App_pyside()
+            elif guiName == 'PYSIDE2':
+                self.guiApp = guiintegration.App_pyside2()
             elif guiName in ['PYQT5', 'QT5']:
                 self.guiApp = guiintegration.App_pyqt5()
             elif guiName in ['PYQT4', 'QT4']:
@@ -495,7 +499,8 @@ class PyzoInterpreter:
         except Exception: # Catch any error
             # Get exception info (we do it using sys.exc_info() because
             # we cannot catch the exception in a version independent way.
-            type, value, tb = sys.exc_info();  del tb
+            type, value, tb = sys.exc_info()
+            del tb
             guiError = 'Failed to integrate event loop for %s: %s' % (
                 guiName, str(value))
         
@@ -522,7 +527,7 @@ class PyzoInterpreter:
             return
         
         # Create an IPython shell
-        from IPython.core.interactiveshell import InteractiveShell 
+        from IPython.core.interactiveshell import InteractiveShell
         self._ipython = InteractiveShell(user_module=__main__)
         
         # Set some hooks / event callbacks
@@ -568,7 +573,8 @@ class PyzoInterpreter:
                 self.ignore_sys_exit = False  # Never allow more than once
                 return
             # Get and store the exception so we can raise it later
-            type, value, tb = sys.exc_info();  del tb
+            type, value, tb = sys.exc_info()
+            del tb
             self._exitException = value
             # Stop debugger if it is running
             self.debugger.stopinteraction()
@@ -585,7 +591,7 @@ class PyzoInterpreter:
             self._codeToRunOnStartup, tmp = None, self._codeToRunOnStartup
             self.pushline(tmp)
         if self._scriptToRunOnStartup:
-            self.context._stat_interpreter.send('Busy') 
+            self.context._stat_interpreter.send('Busy')
             self._scriptToRunOnStartup, tmp = None, self._scriptToRunOnStartup
             self.runfile(tmp)
         
@@ -610,12 +616,13 @@ class PyzoInterpreter:
                 self.context._stat_interpreter.send('More')
             else:
                 self.context._stat_interpreter.send('Ready')
+            self.context._stat_cd.send(os.getcwd())
         
         
         # Are we still connected?
         if sys.stdin.closed or not self.context.connection_count:
             # Exit from main loop.
-            # This will raise SystemExit and will shut us down in the 
+            # This will raise SystemExit and will shut us down in the
             # most appropriate way
             sys.exit()
         
@@ -626,14 +633,14 @@ class PyzoInterpreter:
             pass # No messages waiting
         
         elif ch is self.context._ctrl_command:
-            # Read command 
+            # Read command
             line1 = self.context._ctrl_command.recv(False) # Command
             if line1:
                 # Notify what we're doing
                 self.context._strm_echo.send(line1)
                 self.context._stat_interpreter.send('Busy')
                 self.newPrompt = True
-                # Convert command 
+                # Convert command
                 # (only a few magics are supported if IPython is active)
                 line2 = self.magician.convert_command(line1.rstrip('\n'))
                 # Execute actual code
@@ -695,7 +702,7 @@ class PyzoInterpreter:
         more = self._runlines(source, self._filename)
         # Create buffer if needed
         if more:
-            self._buffer = buffer 
+            self._buffer = buffer
         return more
     
 
@@ -772,6 +779,12 @@ class PyzoInterpreter:
         cellName = msg.get('cellName', '')
         source += '\n'
         
+        # Change directory?
+        if msg.get('changeDir', False) and os.path.isfile(fname):
+            d = os.path.normpath(os.path.normcase(os.path.dirname(fname)))
+            if d != os.getcwd():
+                os.chdir(d)
+        
         # Construct notification message
         lineno1 = lineno + 1
         lineno2 = lineno + source.count('\n')
@@ -780,11 +793,6 @@ class PyzoInterpreter:
             fname_show = os.path.split(fname)[1]
         if cellName == fname:
             runtext = '(executing file "%s")\n' % fname_show
-            if os.path.isfile(fname):
-                d = os.path.normpath(os.path.normcase(os.path.dirname(fname)))
-                if d != os.getcwd():
-                    # print('Changing directory to', d)
-                    os.chdir(d)
         elif cellName:
             runtext = '(executing cell "%s" (line %i of "%s"))\n' % (cellName, lineno1, fname_show)
         elif lineno1 == lineno2:
@@ -807,9 +815,9 @@ class PyzoInterpreter:
         
         # Try compiling the source
         code = None
-        try:            
+        try:
             # Compile
-            code = self.compilecode(source, fname, "exec")          
+            code = self.compilecode(source, fname, "exec")
             
         except (OverflowError, SyntaxError, ValueError):
             self.showsyntaxerror(fname)
@@ -826,25 +834,30 @@ class PyzoInterpreter:
     
     
     def runfile(self, fname):
-        """  To execute the startup script. """ 
+        """  To execute the startup script. """
         
         # Get text (make sure it ends with a newline)
         try:
-            source = open(fname, 'rb').read().decode('UTF-8')
+            bb = open(fname, 'rb').read()
+            encoding = 'UTF-8'
+            firstline = bb.split('\n'.encode(), 1)[0].decode('ascii', 'ignore')
+            if firstline.startswith('#') and 'coding' in firstline:
+                encoding = firstline.split('coding', 1)[-1].strip(' \t\r\n:=-*')
+            source = bb.decode(encoding)
         except Exception:
-            printDirect('Could not read script (decoding using UTF-8): "' + fname + '"\n')
+            printDirect('Could not read script (decoding using %s): %r\n' % (encoding, fname))
             return
         try:
             source = source.replace('\r\n', '\n').replace('\r','\n')
             if source[-1] != '\n':
                 source += '\n'
-        except Exception:        
+        except Exception:
             printDirect('Could not execute script: "' + fname + '"\n')
             return
         
         # Try compiling the source
         code = None
-        try:            
+        try:
             # Compile
             code = self.compilecode(source, fname, "exec")
         except (OverflowError, SyntaxError, ValueError):
@@ -864,7 +877,7 @@ class PyzoInterpreter:
     
     def compilecode(self, source, filename, mode, *args, **kwargs):
         """ Compile source code.
-        Will mangle coding definitions on first two lines. 
+        Will mangle coding definitions on first two lines.
         
         * This method should be called with Unicode sources.
         * Source newlines should consist only of LF characters.
@@ -918,7 +931,7 @@ class PyzoInterpreter:
                 # Turn debugger on at this point. If there are no breakpoints,
                 # the tracing is disabled for better performance.
                 self.apply_breakpoints()
-                self.debugger.set_on() 
+                self.debugger.set_on()
                 exec(code, self.locals)
         except bdb.BdbQuit:
             self.dbstop_handler()
@@ -953,7 +966,7 @@ class PyzoInterpreter:
         """ Hook that IPython calls right before executing code.
         """
         self.apply_breakpoints()
-        self.debugger.set_on() 
+        self.debugger.set_on()
     
     
     def ipython_editor_hook(self, ipython, filename, linenum=None, wait=True):
@@ -995,17 +1008,18 @@ class PyzoInterpreter:
     
     def showsyntaxerror(self, filename=None):
         """Display the syntax error that just occurred.
-        This doesn't display a stack trace because there isn't one.        
+        This doesn't display a stack trace because there isn't one.
         If a filename is given, it is stuffed in the exception instead
         of what was there before (because Python's parser always uses
         "<string>" when reading from a string).
         
         Pyzo version: support to display the right line number,
-        see doc of showtraceback for details.        
+        see doc of showtraceback for details.
         """
         
         # Get info (do not store)
-        type, value, tb = sys.exc_info();  del tb
+        type, value, tb = sys.exc_info()
+        del tb
         
         # Work hard to stuff the correct filename in the exception
         if filename and type is SyntaxError:
@@ -1022,7 +1036,7 @@ class PyzoInterpreter:
                 value = SyntaxError(msg, (fname, lineno, offset, line))
                 sys.last_value = value
         
-        # Show syntax error 
+        # Show syntax error
         strList = traceback.format_exception_only(type, value)
         for s in strList:
             self.write(s)
@@ -1035,15 +1049,15 @@ class PyzoInterpreter:
         
         In the pyzo version, before executing a block of code,
         the filename is modified by appending " [x]". Where x is
-        the index in a list that we keep, of tuples 
-        (sourcecode, filename, lineno). 
+        the index in a list that we keep, of tuples
+        (sourcecode, filename, lineno).
         
-        Here, showing the traceback, we check if we see such [x], 
+        Here, showing the traceback, we check if we see such [x],
         and if so, we extract the line of code where it went wrong,
         and correct the lineno, so it will point at the right line
         in the editor if part of a file was executed. When the file
         was modified since the part in question was executed, the
-        fileno might deviate, but the line of code shown shall 
+        fileno might deviate, but the line of code shown shall
         always be correct...
         """
         # Traceback info:
@@ -1090,7 +1104,7 @@ class PyzoInterpreter:
             
             # Walk through the list
             for i in range(len(tblist)):
-                tbInfo = tblist[i]                
+                tbInfo = tblist[i]
                 # Get filename and line number, init example
                 fname, lineno = self.correctfilenameandlineno(tbInfo[0], tbInfo[1])
                 if not isinstance(fname, ustr):
@@ -1114,14 +1128,17 @@ class PyzoInterpreter:
             frames = None
         
         except Exception:
-            self.write('An error occured, but could not write traceback.\n')
+            type, value, tb = sys.exc_info()
             tb = None
             frames = None
+            t = 'An error occured, but then another one when trying to write the traceback: '
+            t += str(value) + '\n'
+            self.write(t)
     
     
     def correctfilenameandlineno(self, fname, lineno):
         """ Given a filename and lineno, this function returns
-        a modified (if necessary) version of the two. 
+        a modified (if necessary) version of the two.
         As example:
         "foo.py+7", 22  -> "foo.py", 29
         """
@@ -1160,14 +1177,17 @@ class ExecutedSourceCollection:
                 return [line+'\n' for line in src.splitlines()]
             else:
                 import linecache
-                return linecache._getlines(filename, module_globals)
+                if module_globals is None:
+                    return linecache._getlines(filename)  # only valid sig in 2.4
+                else:
+                    return linecache._getlines(filename, module_globals)
         
         # Monkey patch
         import linecache
         linecache._getlines = linecache.getlines
         linecache.getlines =getlines
         
-        # I hoped this would remove the +lineno for IPython tracebacks, 
+        # I hoped this would remove the +lineno for IPython tracebacks,
         # but it doesn't
 #         def extract_tb(tb, limit=None):
 #             print('aasdasd')
@@ -1178,7 +1198,7 @@ class ExecutedSourceCollection:
 #                 filename, lineno = sys._pyzoInterpreter.correctfilenameandlineno(filename, lineno)
 #                 list2.append((filename, lineno, name, line))
 #             return list2
-#         
+#
 #         import traceback
 #         traceback._extract_tb = traceback.extract_tb
 #         traceback.extract_tb = extract_tb
