@@ -4,7 +4,7 @@
 # Pyzo is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
 
-""" 
+"""
 Magic commands for the Pyzo kernel.
 No need to use printDirect here, magic commands are just like normal Python
 commands, in the sense that they print something etc.
@@ -20,7 +20,7 @@ import inspect
 # Set Python version and get some names
 PYTHON_VERSION = sys.version_info[0]
 if PYTHON_VERSION < 3:
-    input = raw_input
+    input = raw_input  # noqa
 
 MESSAGE = """List of *magic* commands:
     ?               - show this message
@@ -34,8 +34,11 @@ MESSAGE = """List of *magic* commands:
     timeit X        - times execution of command X
     open X          - open file X or the Python module that defines object X
     run X           - run file X
-    pip             - manage packages using pip
+    install         - install a new package
+    update          - update an installed package
+    remove          - remove (i.e. uninstall) an installed package
     conda           - manage packages using conda
+    pip             - manage packages using pip
     db X            - debug commands
     cls             - clear screen
     notebook        - launch the Jupyter notebook
@@ -71,7 +74,7 @@ class Magician:
         """ convert_command(line)
         
         Convert a given command from a magic command to Python code.
-        Returns the converted command if it was a magic command, or 
+        Returns the converted command if it was a magic command, or
         the original otherwise.
         
         """
@@ -127,6 +130,19 @@ class Magician:
         elif command.startswith('NOTEBOOK'):
             return self.notebook(line, command)
         
+        elif command.startswith('INSTALL'):
+            return self.install(line, command)
+        
+        elif command.startswith('UPDATE') or command.startswith('UPGRADE'):
+            line = line.replace('upgrade', 'update')
+            command = command.replace('UPGRADE', 'UPDATE')
+            return self.update(line, command)
+        
+        elif command.startswith('REMOVE') or command.startswith('UNINSTALL'):
+            line = line.replace('uninstall', 'remove')
+            command = command.replace('UNINSTALL', 'REMOVE')
+            return self.remove(line, command)
+        
         elif command.startswith('CONDA'):
             return self.conda(line, command)
         
@@ -144,7 +160,6 @@ class Magician:
             
             # EDIT do not run code after editing
             if command.startswith('EDIT ') and not ' -X ' in command:
-                parts = line.split(' ')
                 return 'edit -x ' + line[5:]
             
             # In all cases stop processing magic commands
@@ -288,7 +303,7 @@ class Magician:
             print("There are no variables defined in this scope.")
             return ''
         else:
-            text = "VARIABLE: ".ljust(20,' ') + "TYPE: ".ljust(20,' ') 
+            text = "VARIABLE: ".ljust(20,' ') + "TYPE: ".ljust(20,' ')
             text += "REPRESENTATION: ".ljust(20,' ') + '\n'
         # Create list item for each variablee
         for name in L:
@@ -309,7 +324,7 @@ class Magician:
     
     def open(self, line, command):
         
-        # Get what to open            
+        # Get what to open
         name = line.split(' ',1)[1].strip()
         fname = ''
         linenr = None
@@ -376,7 +391,7 @@ class Magician:
     
     def run(self, line, command):
         
-        # Get what to open            
+        # Get what to open
         name = line.split(' ',1)[1].strip()
         fname = ''
         
@@ -401,6 +416,45 @@ class Magician:
         return ''
     
     
+    def install(self, line, command):
+        if not (command == 'INSTALL' or command.startswith('INSTALL ')):
+            return
+        
+        text = "\x1b[34m\x1b[1m"
+        text += "Trying installation via conda. If this does not work, try:\n"
+        text += "   pip " + line + "\n"
+        text += "\x1b[0m"
+        print(text)
+        time.sleep(0.2)
+        self.conda('conda ' + line, 'CONDA')
+        return ''
+    
+    def update(self, line, command):
+        if not (command == 'UPDATE' or command.startswith('UPDATE ')):
+            return
+        
+        text = "\x1b[34m\x1b[1m"
+        text += "Trying update via conda. If this does not work, try:\n"
+        text += "   pip " + line.replace('update', 'install') + " --upgrade\n"
+        text += "\x1b[0m"
+        print(text)
+        time.sleep(0.2)
+        self.conda('conda ' + line, 'CONDA')
+        return ''
+    
+    def remove(self, line, command):
+        if not (command == 'REMOVE' or command.startswith('REMOVE ')):
+            return
+        
+        text = "\x1b[34m\x1b[1m"
+        text += "Trying remove via conda. If this does not work, try:\n"
+        text += "   pip " + line.replace('remove', 'uninstall') + "\n"
+        text += "\x1b[0m"
+        print(text)
+        time.sleep(0.2)
+        self.conda('conda ' + line, 'CONDA')
+        return ''
+    
     def conda(self, line, command):
         
         if not (command == 'CONDA' or command.startswith('CONDA ')):
@@ -418,17 +472,23 @@ class Magician:
         # Add channels when using install, this gets added last, so
         # that user-specified channels take preference
         channel_list = []
-        if args[0] == 'install':
+        if args and args[0] == 'install':
             channel_list = ['-c', 'conda-forge', '-c', 'pyzo']
         
+        def write_no_dots(x):
+            if x.strip() == '.':  # note, no "x if y else z" in Python 2.4
+                return 0
+            return stderr_write(x)
+        
         # Go!
         # Weird double-try, to make work on Python 2.4
         oldargs = sys.argv
         stderr_write = sys.stderr.write
         try:
             try:
-                sys.stderr.write = lambda x: len(x)
-                import conda
+                # older version of conda would spew dots to stderr during downloading
+                sys.stderr.write = write_no_dots
+                import conda  # noqa
                 from conda.cli import main
                 sys.argv = ['conda'] + list(args) + channel_list
                 main()
@@ -449,7 +509,7 @@ class Magician:
     
     # todo: I think we can deprecate this
     def _check_imported_modules(self):
-        KNOWN_PURE_PYHON = ('conda', 'yaml', 'IPython', 'requests', 
+        KNOWN_PURE_PYHON = ('conda', 'yaml', 'IPython', 'requests',
                             'readline', 'pyreadline')
         if not sys.platform.startswith('win'):
             return  # Only a problem on Windows
@@ -469,7 +529,7 @@ class Magician:
         if loaded_modules:
             print('WARNING! The following modules are currently loaded:\n')
             print('  ' + ', '.join(sorted(loaded_modules)))
-            print('\nUpdating or removing them may fail if they are not ' 
+            print('\nUpdating or removing them may fail if they are not '
                   'pure Python.\nIf none of the listed packages is updated or '
                   'removed, it is safe\nto proceed (use "f" if necessary).\n')
             print('-'*80)
@@ -495,7 +555,7 @@ class Magician:
         
         # Go!
         try:
-            from pyzokernel.pipper import pip_command 
+            from pyzokernel.pipper import pip_command
             pip_command(*args)
         except SystemExit:  # as err:
             type, err, tb = sys.exc_info(); del tb
@@ -543,4 +603,4 @@ class Magician:
         finally:
             sys.argv = oldargs
         
-        return ''
\ No newline at end of file
+        return ''
