@@ -38,6 +38,7 @@ import os, sys, imp
 import pyzo
 from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
 from pyzo.util import zon as ssdf
+from pyzo import translate
 
 
 class ToolDockWidget(QtWidgets.QDockWidget):
@@ -210,7 +211,7 @@ class ToolManager(QtCore.QObject):
                     if i<0: continue
                     line = line.rstrip("\n").rstrip("\r")
                     line = line[i+1:].strip(" ")
-                    toolName = line.strip("'").strip('"')
+                    toolName = eval(line)  # applies translation
                 elif line.startswith("tool_summary"):
                     i = line.find("=")
                     if i<0: continue
