@@ -8,7 +8,7 @@ import pyzo
 from pyzo.util.qt import QtCore, QtGui, QtWidgets
 from pyzo import translate
 
-tool_name = "Source structure"
+tool_name = translate('pyzoSourceStructure', 'Source structure')
 tool_summary = "Shows the structure of your source code."
 
 
@@ -169,7 +169,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
             self._currentEditorId = id(editor)
             
             # Notify
-            text = translate('pyzoSourceStructure', 'Parsing ' + editor._name + ' ...')
+            text = translate('pyzoSourceStructure', 'Parsing ') + editor._name + ' ...'
             QtWidgets.QTreeWidgetItem(self._tree, [text])
             
             # Try getting the  structure right now
@@ -254,9 +254,12 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         ln += 1  # is ln as in line number area
         
         # Define colours
-        colours = {'cell':'#007F00', 'class':'#0000FF', 'def':'#007F7F',
-                    'attribute':'#444444', 'import':'#8800BB', 'todo':'#FF3333',
-                    'nameismain':'#007F00'}
+        colours = {'cell':'#b58900', 'class':'#cb4b16', 'def':'#073642',
+                   'attribute':'#657b83', 'import':'#268bd2', 'todo':'#d33682',
+                   'nameismain':'#859900'}
+        #colours = {'cell':'#007F00', 'class':'#0000FF', 'def':'#007F7F',
+        #            'attribute':'#444444', 'import':'#8800BB', 'todo':'#FF3333',
+        #            'nameismain':'#007F00'}
         
         # Define what to show
         showTypes = self._config.showTypes
@@ -275,17 +278,21 @@ class PyzoSourceStructure(QtWidgets.QWidget):
                 if type not in showTypes and type != 'nameismain':
                     continue
                 # Construct text
-                if type in ('cell', '##', '#%%', '# %%'):
-                    type = 'cell:'
-                elif type=='attribute':
-                    type = 'attr'
-                #
                 if type == 'import':
-                    text = "%s (%s)" % (object.name, object.text)
+                    text = "→ %s (%s)" % (object.name, object.text)
                 elif type=='todo':
                     text = object.name
                 elif type=='nameismain':
                     text = object.text
+                elif type=='class':
+                    text = object.name
+                elif type=='def':
+                    text = object.name + '()'
+                elif type=='attribute':
+                    text = '- ' + object.name
+                elif type in ('cell', '##', '#%%', '# %%'):
+                    type = 'cell'
+                    text = '## ' + object.name + ' ' * 120
                 else:
                     text = "%s %s" % (type, object.name)
                 # Create item
@@ -294,6 +301,8 @@ class PyzoSourceStructure(QtWidgets.QWidget):
                 thisItem.setForeground(0, QtGui.QBrush(color))
                 font = thisItem.font(0)
                 font.setBold(True)
+                if type == 'cell':
+                    font.setUnderline(True)
                 thisItem.setFont(0, font)
                 thisItem.linenr = object.linenr
                 # Is this the current item?
